useful_wsi
=================


Installation
--------------

useful_wsi can be installed by unzipping the source code in one directory and using this command: ::

    python setup.py install

You can also install it directly from the Python Package Index with this command: ::

    pip install useful_wsi

Dependencies
-------------
Useful_wsi depends on the python wrapper for openslide. I recommend using anaconda and this set of commands: ::
    
    conda config --add channels defaults
    conda config --add channels bioconda
    conda config --add channels conda-forge
    conda install openslide-python

Licence
--------

See file LICENCE.txt in this folder


Contribute
-----------
useful_wsi is an open-source software. Everyone is welcome to contribute !
